@@ -1,4 +1,4 @@
-# Copyright (C) 2004-2021 Aaron Swartz
+# Copyright (C) 2004-2022 Aaron Swartz
 #                         Alyssa Ross <hi@alyssa.is>
 #                         Anders Damsgaard <anders@adamsgaard.dk>
 #                         Andrey Zelenchuk <azelenchuk@parallels.com>
@@ -6,12 +6,14 @@
 #                         Brian Lalor
 #                         Dean Jackson
 #                         Dmitry Bogatov <KAction@gnu.org>
+#                         Ellen Wang <squeakbat@users.noreply.github.com>
 #                         Erik Hetzner
 #                         Etienne Millon <me@emillon.org>
 #                         François Boulogne <fboulogne sciunto org>
 #                         George Saunders <georgesaunders@gmail.com>
 #                         Jakub Wilk <jwilk@jwilk.net>
 #                         Joey Hess
+#                         Josh Wainwright <git@jawainwright.co.uk>
 #                         Kaashif Hymabaccus <kaashif@kaashif.co.uk>
 #                         Lindsey Smith <lindsey.smith@gmail.com>
 #                         Léo Gaspard <leo@gaspard.io>
@@ -24,7 +26,6 @@
 #                         Thibaut Girka <thib@sitedethib.com>
 #                         W. Trevor King <wking@tremily.us>
 #                         Yannik Sembritzki <yannik@sembritzki.me>
-#                         auouymous <5005204+auouymous@users.noreply.github.com>
 #                         auouymous <au@qzx.com>
 #                         boyska <piuttosto@logorroici.org>
 #                         ryneeverett <ryneeverett@gmail.com>
@@ -53,7 +54,7 @@ import html2text as _html2text
 
 class Config (_configparser.ConfigParser):
     def __init__(self, dict_type=_collections.OrderedDict,
-                 interpolation=_configparser.ExtendedInterpolation(),
+                 interpolation=None,
                  **kwargs):
         super(Config, self).__init__(
             dict_type=dict_type, interpolation=interpolation, **kwargs)
@@ -120,6 +121,9 @@ CONFIG['DEFAULT'] = _collections.OrderedDict((
         # True: Send a single, multi-entry email per feed per rss2email run.
         # False: Send a single email per entry.
         ('digest', str(False)),
+        # multipart/digest: use Content-type: multipart/digest
+        # multipart/mixed: use Content-type: multipart/mixed
+        ('digest-type', 'multipart/digest'),
         # True: Generate Date header based on item's date, when possible.
         # False: Generate Date header based on time sent.
         ('date-header', str(False)),
@@ -156,6 +160,10 @@ CONFIG['DEFAULT'] = _collections.OrderedDict((
         # digest message before it is mailed.
         # Example: digest-post-process = 'rss2email.post_process.downcase downcase_message'
         ('digest-post-process', ''),
+        # The format for the Subject line.  Available attributes are
+        # 'feed', 'feed-name', 'feed-url', 'feed-title'.
+        ('subject-format', '{feed-title}'),
+
         ## HTML conversion
         # True: Send text/html messages when possible.
         # False: Convert HTML to plain text.
@@ -195,10 +203,10 @@ CONFIG['DEFAULT'] = _collections.OrderedDict((
                 '  padding: 5px;\n'
                 '  margin-bottom: 0px;\n'
                 '}\n'
-                '#entry {\n'
+                '.entry {\n'
                 '  border: solid 4px #c3d9ff;\n'
                 '}\n'
-                '#body {\n'
+                '.body {\n'
                 '  margin-left: 5px;\n'
                 '  margin-right: 5px;\n'
                 '}\n')),
