@@ -192,6 +192,33 @@ def webserver_for_test_fetch(queue, num_requests, wait_time):
     finally:
         httpd.server_close()
 
+def webserver_for_test_user_agent(queue):
+    class AgentDumper(NoLogHandler):
+        def do_GET(self):
+            queue.put(self.headers["User-Agent"])
+            super().do_GET()
+
+    httpd = http.server.HTTPServer(('', 0), AgentDumper)
+    try:
+        port = httpd.server_address[1]
+        queue.put(port)
+        httpd.handle_request()
+    finally:
+        httpd.server_close()
+
+def webserver_for_test_if_fetch(queue, timeout):
+    """Spawn a webserver for `timeout` seconds"""
+    httpd = http.server.HTTPServer(('', 0), NoLogHandler)
+    httpd.timeout = timeout
+    try:
+        port = httpd.server_address[1]
+        queue.put(port)
+
+        httpd.handle_request()
+        queue.put("done")
+    finally:
+        httpd.server_close()
+
 class TestFetch(unittest.TestCase):
     "Retrieving feeds from servers"
     def test_delay(self):
@@ -219,6 +246,38 @@ class TestFetch(unittest.TestCase):
         if result == "too fast":
             raise Exception("r2e did not delay long enough!")
 
+    def test_http_user_agent_config(self):
+        http_user_agent = 'my-test-agent'
+        http_user_agent_cfg = """[DEFAULT]
+        to = example@example.com
+        user-agent = {}
+        """.format(http_user_agent)
+
+        queue = multiprocessing.Queue()
+        webserver_proc = multiprocessing.Process(target=webserver_for_test_user_agent, args=(queue,))
+        webserver_proc.start()
+        port = queue.get()
+
+        with ExecContext(http_user_agent_cfg) as ctx:
+            ctx.call("add", 'test', 'http://127.0.0.1:{port}/dummy'.format(port = port))
+            ctx.call("run", "--no-send")
+        self.assertEqual(queue.get(), http_user_agent)
+
+    def test_default_http_user_agent(self):
+        http_default_agent_cfg = """[DEFAULT]
+        to = example@example.com
+        """
+
+        queue = multiprocessing.Queue()
+        webserver_proc = multiprocessing.Process(target=webserver_for_test_user_agent, args=(queue,))
+        webserver_proc.start()
+        port = queue.get()
+
+        with ExecContext(http_default_agent_cfg) as ctx:
+            ctx.call("add", 'test', 'http://127.0.0.1:{port}/dummy'.format(port = port))
+            ctx.call("run", "--no-send")
+        self.assertIn('rss2email/', queue.get(), "rss2email should identify itself as the User-Agent by default")
+
     def test_fetch_parallel(self):
         if not UNIX:
             self.skipTest("No locking on Windows.")
@@ -269,6 +328,28 @@ class TestFetch(unittest.TestCase):
                     previous_line = line
             self.assertTrue(finish_precedes_acquire)
 
+    def test_only_new(self):
+        "Add and fetch contents"
+
+        standard_cfg = """[DEFAULT]
+        to = example@example.com"""
+
+        queue = multiprocessing.Queue()
+        webserver_proc = multiprocessing.Process(target=webserver_for_test_if_fetch, args=(queue, 10))
+        webserver_proc.start()
+        port = queue.get()
+
+        with ExecContext(standard_cfg) as ctx:
+            ctx.call("add", '--only-new', 'test', 'http://127.0.0.1:{port}/disqus/feed.rss'.format(port = port))
+            # check if data is written
+            self.assertTrue(_os.path.exists(ctx.data_path))
+            with ctx.data_path.open('r') as f:
+                content = json.load(f)
+                # check if entries in seen
+                self.assertIn("seen", content["feeds"][0])
+        self.assertEqual(queue.get(), "done")
+
+
 def webserver_for_test_send(queue):
     httpd = http.server.HTTPServer(('', 0), NoLogHandler)
     try:
